@@ -1,8 +1,9 @@
 /*
  *  Hamlib Dummy backend - main file
- *  Copyright (c) 2001-2009 by Stephane Fillod
+ *  Copyright (c) 2001-2010 by Stephane Fillod
+ *  Copyright (c) 2010 by Nate Bargmann
  *
- *	$Id: dummy.c,v 1.44 2009-02-06 17:27:54 fillods Exp $
+ *  $Id: dummy.c,v 1.44 2009-02-06 17:27:54 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -59,9 +60,11 @@ struct dummy_priv_data {
 		channel_t mem[NB_CHAN];
 
 		struct ext_list *ext_parms;
+
+        char *magic_conf;
 };
 
-
+/* levels pertain to each VFO */
 static const struct confparams dummy_ext_levels[] = {
 	{ TOK_EL_MAGICLEVEL, "MGL", "Magic level", "Magic level, as an example",
 		NULL, RIG_CONF_NUMERIC, { .n = { 0, 1, .001 } }
@@ -75,6 +78,7 @@ static const struct confparams dummy_ext_levels[] = {
 	{ RIG_CONF_END, NULL, }
 };
 
+/* parms pertain to the whole rig */
 static const struct confparams dummy_ext_parms[] = {
 	{ TOK_EP_MAGICPARM, "MGP", "Magic parm", "Magic parameter, as an example",
 		NULL, RIG_CONF_NUMERIC, { .n = { 0, 1, .001 } }
@@ -82,6 +86,13 @@ static const struct confparams dummy_ext_parms[] = {
 	{ RIG_CONF_END, NULL, }
 };
 
+/* cfgparams are configuration item generally used by the backend's open() method */
+static const struct confparams dummy_cfg_params[] = {
+	{ TOK_CFG_MAGICCONF, "mcfg", "Magic conf", "Magic parameter, as an example",
+		"DX", RIG_CONF_STRING, { }
+	},
+	{ RIG_CONF_END, NULL, }
+};
 
 /********************************************************************/
 
@@ -114,6 +125,23 @@ static void init_chan(RIG *rig, vfo_t vfo, channel_t *chan)
   memset(chan->levels, 0, RIG_SETTING_MAX*sizeof(value_t));
 }
 
+static void copy_chan(channel_t *dest, const channel_t *src)
+{
+    struct ext_list *saved_ext_levels;
+    int i;
+
+    /* TODO: ext_levels[] of different sizes */
+
+    for (i=0; !RIG_IS_EXT_END(src->ext_levels[i]) &&
+            !RIG_IS_EXT_END(dest->ext_levels[i]); i++) {
+        dest->ext_levels[i] = src->ext_levels[i];
+    }
+
+    saved_ext_levels = dest->ext_levels;
+    memcpy(dest, src, sizeof(channel_t));
+    dest->ext_levels = saved_ext_levels;
+}
+
 static struct ext_list * alloc_init_ext(const struct confparams *cfp)
 {
   struct ext_list *elp;
@@ -193,6 +221,8 @@ static int dummy_init(RIG *rig)
   priv->curr = &priv->vfo_a;
   priv->curr_vfo = priv->last_vfo = RIG_VFO_A;
 
+  priv->magic_conf = strdup("DX");
+
   return RIG_OK;
 }
 
@@ -209,6 +239,7 @@ static int dummy_cleanup(RIG *rig)
   free(priv->vfo_a.ext_levels);
   free(priv->vfo_b.ext_levels);
   free(priv->ext_parms);
+  free(priv->magic_conf);
 
   if (rig->state.priv)
   	free(rig->state.priv);
@@ -232,6 +263,41 @@ static int dummy_close(RIG *rig)
   return RIG_OK;
 }
 
+static int dummy_set_conf(RIG *rig, token_t token, const char *val)
+{
+	struct dummy_priv_data *priv;
+
+	priv = (struct dummy_priv_data*)rig->state.priv;
+
+	switch(token) {
+		case TOK_CFG_MAGICCONF:
+            if (val) {
+                free(priv->magic_conf);
+                priv->magic_conf = strdup(val);
+            }
+			break;
+		default:
+			return -RIG_EINVAL;
+	}
+	return RIG_OK;
+}
+
+static int dummy_get_conf(RIG *rig, token_t token, char *val)
+{
+	struct dummy_priv_data *priv;
+
+	priv = (struct dummy_priv_data*)rig->state.priv;
+
+	switch(token) {
+		case TOK_CFG_MAGICCONF:
+			strcpy(val, priv->magic_conf);
+			break;
+		default:
+			return -RIG_EINVAL;
+	}
+	return RIG_OK;
+}
+
 static int dummy_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
   struct dummy_priv_data *priv = (struct dummy_priv_data *)rig->state.priv;
@@ -239,7 +305,7 @@ static int dummy_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
   char fstr[20];
 
   sprintf_freq(fstr, freq);
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", __FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", __FUNCTION__,
  			rig_strvfo(vfo), fstr);
   curr->freq = freq;
 
@@ -267,7 +333,7 @@ static int dummy_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
   char buf[16];
 
   sprintf_freq(buf, width);
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s %s\n", __FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s %s\n", __FUNCTION__,
   		rig_strvfo(vfo), rig_strrmode(mode), buf);
 
   curr->mode = mode;
@@ -305,7 +371,7 @@ static int dummy_set_vfo(RIG *rig, vfo_t vfo)
 
   case RIG_VFO_A: priv->curr = &priv->vfo_a; break;
   case RIG_VFO_B: priv->curr = &priv->vfo_b; break;
-  case RIG_VFO_MEM: 
+  case RIG_VFO_MEM:
 				  if (curr->channel_num >= 0 && curr->channel_num < NB_CHAN) {
 						  priv->curr = &priv->mem[curr->channel_num];
 						  break;
@@ -513,7 +579,7 @@ static int dummy_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
   char fstr[20];
 
   sprintf_freq(fstr, tx_freq);
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", __FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", __FUNCTION__,
  			rig_strvfo(vfo), fstr);
   curr->tx_freq = tx_freq;
 
@@ -662,14 +728,12 @@ static int dummy_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
   struct dummy_priv_data *priv = (struct dummy_priv_data *)rig->state.priv;
   channel_t *curr = priv->curr;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %d\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %d\n",__FUNCTION__,
 				  rig_strfunc(func), status);
-  if (func < RIG_SETTING_MAX) {
-		if (status)
-			curr->funcs |=  func;
-  		else
-			curr->funcs &= ~func;
-  }
+  if (status)
+	curr->funcs |=  func;
+  else
+	curr->funcs &= ~func;
 
   return RIG_OK;
 }
@@ -680,10 +744,9 @@ static int dummy_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
   struct dummy_priv_data *priv = (struct dummy_priv_data *)rig->state.priv;
   channel_t *curr = priv->curr;
 
-  if (func < RIG_SETTING_MAX)
-		*status = curr->funcs & func ? 1 : 0;
+  *status = curr->funcs & func ? 1 : 0;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__,
 				  rig_strfunc(func));
 
   return RIG_OK;
@@ -698,14 +761,16 @@ static int dummy_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
   char lstr[32];
 
   idx = rig_setting2idx(level);
-  if (idx < RIG_SETTING_MAX)
-  	curr->levels[idx] = val;
+  if (idx >= RIG_SETTING_MAX)
+      return -RIG_EINVAL;
+
+  curr->levels[idx] = val;
 
   if (RIG_LEVEL_IS_FLOAT(level))
 		  sprintf(lstr, "%f", val.f);
   else
 		  sprintf(lstr, "%d", val.i);
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",__FUNCTION__,
 				  rig_strlevel(level), lstr);
 
   return RIG_OK;
@@ -720,15 +785,27 @@ static int dummy_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
   idx = rig_setting2idx(level);
 
+  if (idx >= RIG_SETTING_MAX)
+      return -RIG_EINVAL;
+
   /* make S-Meter jiggle */
-  if (level == RIG_LEVEL_STRENGTH || level == RIG_LEVEL_RAWSTR)
-  	curr->levels[idx].i = -30 + time(NULL)%32 + rand()%4 
+  if (level == RIG_LEVEL_STRENGTH || level == RIG_LEVEL_RAWSTR) {
+
+  	int qrm = -56;
+    if (curr->freq < MHz(7))
+        qrm = -20;
+    else if (curr->freq < MHz(21))
+        qrm = -30;
+    else if (curr->freq < MHz(50))
+        qrm = -50;
+
+  	curr->levels[idx].i = qrm + time(NULL)%32 + rand()%4
 		- curr->levels[LVL_ATT].i
 		+ curr->levels[LVL_PREAMP].i;
+  }
 
-  if (idx < RIG_SETTING_MAX)
-  	*val = curr->levels[idx];
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__, 
+  *val = curr->levels[idx];
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__,
 				  rig_strlevel(level));
 
   return RIG_OK;
@@ -782,7 +859,7 @@ static int dummy_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val)
   /* store value */
   elp->val = val;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",__FUNCTION__,
 				  cfp->name, lstr);
 
   return RIG_OK;
@@ -815,7 +892,7 @@ static int dummy_get_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t *val)
   /* load value */
   *val = elp->val;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__,
 				  cfp->name);
 
   return RIG_OK;
@@ -851,15 +928,16 @@ static int dummy_set_parm(RIG *rig, setting_t parm, value_t val)
   char pstr[32];
 
   idx = rig_setting2idx(parm);
+  if (idx >= RIG_SETTING_MAX)
+      return -RIG_EINVAL;
 
   if (RIG_PARM_IS_FLOAT(parm))
 		  sprintf(pstr, "%f", val.f);
   else
 		  sprintf(pstr, "%d", val.i);
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", __FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", __FUNCTION__,
 				  rig_strparm(parm), pstr);
-  if (idx < RIG_SETTING_MAX)
-  	priv->parms[idx] = val;
+  priv->parms[idx] = val;
 
   return RIG_OK;
 }
@@ -871,10 +949,11 @@ static int dummy_get_parm(RIG *rig, setting_t parm, value_t *val)
   int idx;
 
   idx = rig_setting2idx(parm);
+  if (idx >= RIG_SETTING_MAX)
+      return -RIG_EINVAL;
 
-  if (idx < RIG_SETTING_MAX)
-  	*val = priv->parms[idx];
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called %s\n",__FUNCTION__, 
+  *val = priv->parms[idx];
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called %s\n",__FUNCTION__,
 				  rig_strparm(parm));
 
   return RIG_OK;
@@ -926,7 +1005,7 @@ static int dummy_set_ext_parm(RIG *rig, token_t token, value_t val)
   epp->val = val;
 
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",__FUNCTION__,
 				  cfp->name, lstr);
 
   return RIG_OK;
@@ -958,7 +1037,7 @@ static int dummy_get_ext_parm(RIG *rig, token_t token, value_t *val)
   /* load value */
   *val = epp->val;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__,
 				  cfp->name);
 
   return RIG_OK;
@@ -1007,6 +1086,9 @@ static int dummy_set_mem(RIG *rig, vfo_t vfo, int ch)
 
   rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __FUNCTION__);
 
+  if (ch < 0 || ch >= NB_CHAN)
+	return -RIG_EINVAL;
+
   if (priv->curr_vfo == RIG_VFO_MEM)
 		  priv->curr = &priv->mem[ch];
   else
@@ -1029,9 +1111,9 @@ static int dummy_get_mem(RIG *rig, vfo_t vfo, int *ch)
 
 static int dummy_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
 {
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %d\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %d\n",__FUNCTION__,
 				  rig_strscan(scan), ch);
-
+  /* TODO: change freq, etc. */
   return RIG_OK;
 }
 
@@ -1049,21 +1131,21 @@ static int dummy_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
   freq_t freq;
   shortfreq_t ts;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__,
 				  rig_strvfop(op));
 
   switch (op) {
 	  case RIG_OP_FROM_VFO:	/* VFO->MEM */
 			  if (priv->curr_vfo == RIG_VFO_MEM) {
 				int ch = curr->channel_num;
-			  	memcpy(curr, priv->last_vfo == RIG_VFO_A ?
-							  &priv->vfo_a : &priv->vfo_b, sizeof(channel_t));
+			  	copy_chan(curr, priv->last_vfo == RIG_VFO_A ?
+							  &priv->vfo_a : &priv->vfo_b);
 				curr->channel_num = ch;
 				curr->channel_desc[0] = '\0';
 				curr->vfo = RIG_VFO_MEM;
 			  } else {
 				channel_t *mem_chan = &priv->mem[curr->channel_num];
-			  	memcpy(mem_chan, curr, sizeof(channel_t));
+			  	copy_chan(mem_chan, curr);
 				mem_chan->channel_num = curr->channel_num;
 				mem_chan->channel_desc[0] = '\0';
 				mem_chan->vfo = RIG_VFO_MEM;
@@ -1071,51 +1153,85 @@ static int dummy_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 			  break;
 	  case RIG_OP_TO_VFO:         /* MEM->VFO */
 			  if (priv->curr_vfo == RIG_VFO_MEM) {
-			    channel_t *vfo_chan = (priv->last_vfo == RIG_VFO_A) ? 
+			    channel_t *vfo_chan = (priv->last_vfo == RIG_VFO_A) ?
 											&priv->vfo_a : &priv->vfo_b;
-			  	memcpy(vfo_chan, curr, sizeof(channel_t));
+			  	copy_chan(vfo_chan, curr);
 				chan_vfo(vfo_chan, priv->last_vfo);
 			  } else {
-			  	memcpy(&priv->mem[curr->channel_num], 
-								curr, sizeof(channel_t));
+			  	copy_chan(&priv->mem[curr->channel_num], curr);
 				chan_vfo(curr, priv->curr_vfo);
 			  }
 			  break;
 	  case RIG_OP_CPY:	 /* VFO A = VFO B   or   VFO B = VFO A */
 			  if (priv->curr_vfo == RIG_VFO_A) {
-			  	memcpy(&priv->vfo_b, &priv->vfo_a, sizeof(channel_t));
+			  	copy_chan(&priv->vfo_b, &priv->vfo_a);
 				chan_vfo(&priv->vfo_b, RIG_VFO_B);
 				break;
 			  } else if (priv->curr_vfo == RIG_VFO_B) {
-			  	memcpy(&priv->vfo_a, &priv->vfo_b, sizeof(channel_t));
+			  	copy_chan(&priv->vfo_a, &priv->vfo_b);
 				chan_vfo(&priv->vfo_a, RIG_VFO_A);
 				break;
 			  }
   			  rig_debug(RIG_DEBUG_VERBOSE,"%s beep!\n", __FUNCTION__ );
 			  break;
-	  case RIG_OP_XCHG: /* Exchange VFO A/B */ 
+	  case RIG_OP_XCHG: /* Exchange VFO A/B */
 			  {
 				channel_t chan;
-			  	memcpy(&chan, &priv->vfo_b, sizeof(channel_t));
-			  	memcpy(&priv->vfo_b, &priv->vfo_a, sizeof(channel_t));
-			  	memcpy(&priv->vfo_a, &chan, sizeof(channel_t));
+				chan.ext_levels = alloc_init_ext(dummy_ext_levels);
+				if (!chan.ext_levels)
+					return -RIG_ENOMEM;
+			  	copy_chan(&chan, &priv->vfo_b);
+			  	copy_chan(&priv->vfo_b, &priv->vfo_a);
+			  	copy_chan(&priv->vfo_a, &chan);
 				chan_vfo(&priv->vfo_a, RIG_VFO_A);
 				chan_vfo(&priv->vfo_b, RIG_VFO_B);
+				free(chan.ext_levels);
 				break;
 			  }
 	  case RIG_OP_MCL:	/* Memory clear */
 			  if (priv->curr_vfo == RIG_VFO_MEM) {
-					int ch = curr->channel_num;
+					struct ext_list *saved_ext_levels = curr->ext_levels;
+					int saved_ch = curr->channel_num;
+					int i;
+
+					for (i=0; !RIG_IS_EXT_END(curr->ext_levels[i]); i++) {
+						curr->ext_levels[i].val.i = 0;
+					}
 				  	memset(curr, 0, sizeof(channel_t));
-					curr->channel_num = ch;
+					curr->ext_levels = saved_ext_levels;
+					curr->channel_num = saved_ch;
 					curr->vfo = RIG_VFO_MEM;
 			  } else {
+					struct ext_list *saved_ext_levels = curr->ext_levels;
 					channel_t *mem_chan = &priv->mem[curr->channel_num];
+					int i;
+
+					for (i=0; !RIG_IS_EXT_END(mem_chan->ext_levels[i]); i++) {
+						mem_chan->ext_levels[i].val.i = 0;
+					}
 				  	memset(mem_chan, 0, sizeof(channel_t));
+					mem_chan->ext_levels = saved_ext_levels;
 					mem_chan->channel_num = curr->channel_num;
 					mem_chan->vfo = RIG_VFO_MEM;
 			  }
 			  break;
+	  case RIG_OP_TOGGLE:
+			  if (priv->curr_vfo == RIG_VFO_A)
+				return dummy_set_vfo(rig, RIG_VFO_B);
+              else if (priv->curr_vfo == RIG_VFO_B)
+				return dummy_set_vfo(rig, RIG_VFO_A);
+              else
+				return -RIG_EVFO;
+
+	  case RIG_OP_RIGHT:
+	  case RIG_OP_LEFT:
+	  case RIG_OP_TUNE:
+			  /* NOP */
+			  break;
+	  case RIG_OP_BAND_UP:
+	  case RIG_OP_BAND_DOWN:
+		return -RIG_ENIMPL;
+
 	case RIG_OP_UP:
 		ret = dummy_get_freq(rig, vfo, &freq);
 		if (!ret) break;
@@ -1123,7 +1239,7 @@ static int dummy_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 		if (!ret) break;
 		ret = dummy_set_freq(rig, vfo, freq+ts);	/* up */
 		break;
-        case RIG_OP_DOWN:
+	case RIG_OP_DOWN:
 		ret = dummy_get_freq(rig, vfo, &freq);
 		if (!ret) break;
 		ret = dummy_get_ts(rig, vfo, &ts);
@@ -1144,19 +1260,27 @@ static int dummy_set_channel(RIG *rig, const channel_t *chan)
 
   rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __FUNCTION__);
 
-  /* TODO: check chan->channel_num is in a valid range */
+  if (!chan->ext_levels)
+      return -RIG_EINVAL;
+
+  if (chan->channel_num < 0 || chan->channel_num >= NB_CHAN)
+      return -RIG_EINVAL;
+
+  /* TODO:
+   * - check ext_levels is the right length
+   */
   switch (chan->vfo) {
 	  case RIG_VFO_MEM:
-	  	memcpy(&priv->mem[chan->channel_num], chan, sizeof(channel_t));
+	  	copy_chan(&priv->mem[chan->channel_num], chan);
 		break;
 	  case RIG_VFO_A:
-	  	memcpy(&priv->vfo_a, chan, sizeof(channel_t));
+	  	copy_chan(&priv->vfo_a, chan);
 		break;
 	  case RIG_VFO_B:
-	  	memcpy(&priv->vfo_b, chan, sizeof(channel_t));
+	  	copy_chan(&priv->vfo_b, chan);
 		break;
 	  case RIG_VFO_CURR:
-	  	memcpy(priv->curr, chan, sizeof(channel_t));
+	  	copy_chan(priv->curr, chan);
 		break;
 	  default:
 		return -RIG_EINVAL;
@@ -1172,19 +1296,30 @@ static int dummy_get_channel(RIG *rig, channel_t *chan)
 
   rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __FUNCTION__);
 
-  /* TODO: check chan->channel_num is in a valid range */
+  if (chan->channel_num < 0 || chan->channel_num >= NB_CHAN)
+      return -RIG_EINVAL;
+
+  if (!chan->ext_levels) {
+     chan->ext_levels = alloc_init_ext(dummy_ext_levels);
+     if (!chan->ext_levels)
+         return -RIG_ENOMEM;
+  }
+
+  /* TODO:
+   * - check ext_levels is the right length
+   */
   switch (chan->vfo) {
 	  case RIG_VFO_MEM:
-	  	memcpy(chan, &priv->mem[chan->channel_num], sizeof(channel_t));
+	  	copy_chan(chan, &priv->mem[chan->channel_num]);
 		break;
 	  case RIG_VFO_A:
-	  	memcpy(chan, &priv->vfo_a, sizeof(channel_t));
+	  	copy_chan(chan, &priv->vfo_a);
 		break;
 	  case RIG_VFO_B:
-	  	memcpy(chan, &priv->vfo_b, sizeof(channel_t));
+	  	copy_chan(chan, &priv->vfo_b);
 		break;
 	  case RIG_VFO_CURR:
-	  	memcpy(chan, priv->curr, sizeof(channel_t));
+	  	copy_chan(chan, priv->curr);
 		break;
 	  default:
 		return -RIG_EINVAL;
@@ -1241,27 +1376,53 @@ static int dummy_send_morse(RIG *rig, vfo_t vfo, const char *msg)
   return RIG_OK;
 }
 
+static int dummy_power2mW(RIG * rig, unsigned int *mwpower, float power,
+                          freq_t freq, rmode_t mode)
+{
+    rig_debug(RIG_DEBUG_TRACE, "%s: passed power = %f\n", __func__, power);
+    rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
+    rig_debug(RIG_DEBUG_TRACE, "%s: passed mode = %i\n", __func__, mode);
+
+    /* Pretend this is a 100W radio */
+    *mwpower = (power * 100000);
+
+    return RIG_OK;
+}
+
+
+static int dummy_mW2power(RIG * rig, float *power, unsigned int mwpower,
+                          freq_t freq, rmode_t mode)
+{
+    rig_debug(RIG_DEBUG_TRACE, "%s: passed mwpower = %i\n", __func__, mwpower);
+    rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
+    rig_debug(RIG_DEBUG_TRACE, "%s: passed mode = %i\n", __func__, mode);
+
+    /* Pretend this is a 100W radio */
+    if (mwpower > 100000)
+        return -RIG_EINVAL;
+
+    *power = ((float)mwpower / 100000);
+
+    return RIG_OK;
+}
 
 
 /*
  * Dummy rig capabilities.
  */
 
-#if 0
-#define DUMMY_FUNC  0x7fffffffffffffLL	/* has it all */
-#define DUMMY_LEVEL 0x7ffffffffffffffLL
-#define DUMMY_PARM  0x7ffffffffffffffLL
-#else
-#define DUMMY_FUNC  ((setting_t)-1)	/* has it all */
-#define DUMMY_LEVEL ((setting_t)-1)
+#define DUMMY_FUNC  (((setting_t)-1)&~(0xc1000000U))	/* has it all */
+#define DUMMY_LEVEL (((setting_t)-1)&~(1<<27))
 #define DUMMY_PARM  ((setting_t)-1)
-#endif
 
 #define DUMMY_VFO_OP  0x7ffffffL
 #define DUMMY_SCAN	0x7ffffffL
 
+#define DUMMY_VFOS (RIG_VFO_A|RIG_VFO_B|RIG_VFO_MEM)
+
 #define DUMMY_MODES (RIG_MODE_AM | RIG_MODE_CW | RIG_MODE_RTTY | \
-                     RIG_MODE_SSB | RIG_MODE_FM | RIG_MODE_WFM)
+                     RIG_MODE_SSB | RIG_MODE_FM | RIG_MODE_WFM | \
+                     RIG_MODE_CWR | RIG_MODE_RTTYR)
 
 #define DUMMY_MEM_CAP {    \
 	.bank_num = 1,	\
@@ -1279,8 +1440,8 @@ static int dummy_send_morse(RIG *rig, vfo_t vfo, const char *msg)
 	.tuning_step = 1,	\
 	.rit = 1,	\
 	.xit = 1,	\
-	.funcs = 1,	\
-	.levels = 1,	\
+	.funcs = DUMMY_FUNC,	\
+	.levels = RIG_LEVEL_SET(DUMMY_LEVEL),	\
 	.ctcss_tone = 1,	\
 	.ctcss_sql = 1,	\
 	.dcs_code = 1,	\
@@ -1295,7 +1456,7 @@ const struct rig_caps dummy_caps = {
   .rig_model =      RIG_MODEL_DUMMY,
   .model_name =     "Dummy",
   .mfg_name =       "Hamlib",
-  .version =        "0.4",
+  .version =        "0.5",
   .copyright =      "LGPL",
   .status =         RIG_STATUS_BETA,
   .rig_type =       RIG_TYPE_OTHER,
@@ -1315,7 +1476,7 @@ const struct rig_caps dummy_caps = {
   .chan_list = 	 {
 			{   0,  18, RIG_MTYPE_MEM, DUMMY_MEM_CAP },
 			{  19,  19, RIG_MTYPE_CALL },
-			{  20,  21, RIG_MTYPE_EDGE },
+			{  20,  NB_CHAN-1, RIG_MTYPE_EDGE },
 			RIG_CHAN_END,
 		 },
   .scan_ops = 	 DUMMY_SCAN,
@@ -1323,9 +1484,13 @@ const struct rig_caps dummy_caps = {
   .transceive =     RIG_TRN_OFF,
   .attenuator =     { 10, 20, 30, RIG_DBLST_END, },
   .preamp = 		 { 10, RIG_DBLST_END, },
+  .rx_range_list1 =  { {.start=kHz(150),.end=MHz(1500),.modes=DUMMY_MODES,
+                        .low_power=-1,.high_power=-1,DUMMY_VFOS, RIG_ANT_1|RIG_ANT_2},
+                        RIG_FRNG_END, },
+  .tx_range_list1 =  { RIG_FRNG_END, },
   .rx_range_list2 =  { {.start=kHz(150),.end=MHz(1500),.modes=DUMMY_MODES,
-		    .low_power=-1,.high_power=-1,RIG_VFO_A|RIG_VFO_B, RIG_ANT_1|RIG_ANT_2},
-		    RIG_FRNG_END, },
+                        .low_power=-1,.high_power=-1,DUMMY_VFOS, RIG_ANT_1|RIG_ANT_2},
+                        RIG_FRNG_END, },
   .tx_range_list2 =  { RIG_FRNG_END, },
   .tuning_steps =  { {DUMMY_MODES,1}, {DUMMY_MODES,RIG_TS_ANY}, RIG_TS_END, },
   .filters =  {
@@ -1345,19 +1510,23 @@ const struct rig_caps dummy_caps = {
 
   .extlevels =    dummy_ext_levels,
   .extparms =     dummy_ext_parms,
+  .cfgparams =    dummy_cfg_params,
 
   .rig_init =     dummy_init,
   .rig_cleanup =  dummy_cleanup,
   .rig_open =     dummy_open,
   .rig_close =    dummy_close,
 
+  .set_conf =     dummy_set_conf,
+  .get_conf =     dummy_get_conf,
+
   .set_freq =     dummy_set_freq,
   .get_freq =     dummy_get_freq,
   .set_mode =     dummy_set_mode,
   .get_mode =     dummy_get_mode,
   .set_vfo =      dummy_set_vfo,
   .get_vfo =      dummy_get_vfo,
-  
+
   .set_powerstat =  dummy_set_powerstat,
   .get_powerstat =  dummy_get_powerstat,
   .set_level =     dummy_set_level,
@@ -1415,6 +1584,8 @@ const struct rig_caps dummy_caps = {
   .get_channel = 	dummy_get_channel,
   .set_trn = 	dummy_set_trn,
   .get_trn = 	dummy_get_trn,
+  .power2mW =	dummy_power2mW,
+  .mW2power =	dummy_mW2power,
 };
 
 DECLARE_INITRIG_BACKEND(dummy)
