@@ -1,6 +1,6 @@
 /*
  *  Hamlib CI-V backend - main header
- *  Copyright (c) 2000-2010 by Stephane Fillod
+ *  Copyright (c) 2000-2011 by Stephane Fillod
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -123,6 +123,7 @@ extern const struct ts_sc_list ic737_ts_sc_list[];
 extern const struct ts_sc_list r75_ts_sc_list[];
 extern const struct ts_sc_list r7100_ts_sc_list[];
 extern const struct ts_sc_list r9000_ts_sc_list[];
+extern const struct ts_sc_list r9500_ts_sc_list[];
 extern const struct ts_sc_list ic756_ts_sc_list[];
 extern const struct ts_sc_list ic756pro_ts_sc_list[];
 extern const struct ts_sc_list ic706_ts_sc_list[];
@@ -199,6 +200,7 @@ extern const struct rig_caps ic736_caps;
 extern const struct rig_caps ic737_caps;
 extern const struct rig_caps ic738_caps;
 extern const struct rig_caps ic746_caps;
+extern const struct rig_caps ic7410_caps;
 extern const struct rig_caps ic746pro_caps;
 extern const struct rig_caps ic756_caps;
 extern const struct rig_caps ic756pro_caps;
@@ -218,6 +220,7 @@ extern const struct rig_caps ic781_caps;
 extern const struct rig_caps ic820h_caps;
 extern const struct rig_caps ic821h_caps;
 extern const struct rig_caps ic910_caps;
+extern const struct rig_caps ic9100_caps;
 extern const struct rig_caps ic970_caps;
 extern const struct rig_caps icr10_caps;
 extern const struct rig_caps icr20_caps;
@@ -228,6 +231,7 @@ extern const struct rig_caps icr7000_caps;
 extern const struct rig_caps icr7100_caps;
 extern const struct rig_caps icr8500_caps;
 extern const struct rig_caps icr9000_caps;
+extern const struct rig_caps icr9500_caps;
 extern const struct rig_caps ic271_caps;
 extern const struct rig_caps ic275_caps;
 extern const struct rig_caps ic471_caps;
