@@ -1,7 +1,7 @@
 /*
  *  Hamlib Interface - list of known rigs
  *  Copyright (c) 2000-2003 by Frank Singleton
- *  Copyright (c) 2000-2010 by Stephane Fillod
+ *  Copyright (c) 2000-2011 by Stephane Fillod
  *
  *
  *   This library is free software; you can redistribute it and/or modify
@@ -132,6 +132,8 @@
 #define RIG_MODEL_K3 RIG_MAKE_MODEL(RIG_KENWOOD, 29)
 #define RIG_MODEL_TRC80 RIG_MAKE_MODEL(RIG_KENWOOD, 30)
 #define RIG_MODEL_TS590S RIG_MAKE_MODEL(RIG_KENWOOD, 31)
+#define RIG_MODEL_TRANSFOX RIG_MAKE_MODEL(RIG_KENWOOD, 32)  /* SigFox Transfox */
+#define RIG_MODEL_THD72A RIG_MAKE_MODEL(RIG_KENWOOD, 33)
 
 	/*
 	 * Icom
@@ -195,7 +197,10 @@
 #define RIG_MODEL_IC7700 RIG_MAKE_MODEL(RIG_ICOM, 62)
 #define RIG_MODEL_IC7600 RIG_MAKE_MODEL(RIG_ICOM, 63)
 #define RIG_MODEL_IC92D RIG_MAKE_MODEL(RIG_ICOM, 65)
-/* next one is 66 */
+#define RIG_MODEL_ICR9500 RIG_MAKE_MODEL(RIG_ICOM, 66)
+#define RIG_MODEL_IC7410 RIG_MAKE_MODEL(RIG_ICOM, 67)
+#define RIG_MODEL_IC9100 RIG_MAKE_MODEL(RIG_ICOM, 68)
+/* next one is 69 */
 
 	/*
 	 * Optoelectronics (CI-V)
@@ -479,6 +484,7 @@
 #define RIG_TUNER 26
 #define RIG_BACKEND_TUNER "tuner"
 #define RIG_MODEL_V4L RIG_MAKE_MODEL(RIG_TUNER, 1)
+#define RIG_MODEL_V4L2 RIG_MAKE_MODEL(RIG_TUNER, 2)
 
 	/*
 	 * Rohde&Schwarz
