@@ -1,6 +1,6 @@
 /*
  *  Hamlib Interface - list of known rotators
- *  Copyright (c) 2000-2010 by Stephane Fillod
+ *  Copyright (c) 2000-2011 by Stephane Fillod
  *  Copyright (c) 2000-2002 by Frank Singleton
  *
  *
@@ -243,6 +243,28 @@
 #define ROT_MODEL_RCI_AZEL ROT_MAKE_MODEL(ROT_ARS, 1)
 #define ROT_MODEL_RCI_AZ ROT_MAKE_MODEL(ROT_ARS, 2)
 
+/*! \def ROT_MODEL_IF100
+ *  \brief A macro that returns the model number of the IF-100 backend.
+ *
+ *  The AMSAT backend can be used with rotators that support,
+ *  among other, the IF-100 interface.
+ */
+#define ROT_AMSAT 12
+#define ROT_BACKEND_AMSAT "amsat"
+#define ROT_MODEL_IF100 ROT_MAKE_MODEL(ROT_AMSAT, 1)
+
+
+/*! \def ROT_MODEL_TS7400
+ *  \brief A macro that returns the model number of the TS7400 backend.
+ *
+ *  The TS-7400 backend supports and embedded ARM board using the TS-7400
+ *  Linux board.  More information is at http://www.embeddedarm.com
+ */
+#define ROT_TS7400 13
+#define ROT_BACKEND_TS7400 "ts7400"
+#define ROT_MODEL_TS7400 ROT_MAKE_MODEL(ROT_TS7400, 1)
+
+
 /*! \typedef typedef int rot_model_t
     \brief Convenience type definition for rotator model.
 */
@@ -268,6 +290,8 @@ typedef int rot_model_t;
         { ROT_SPID, ROT_BACKEND_SPID }, \
         { ROT_M2, ROT_BACKEND_M2 }, \
         { ROT_ARS, ROT_BACKEND_ARS }, \
+        { ROT_AMSAT, ROT_BACKEND_AMSAT }, \
+        { ROT_TS7400, ROT_BACKEND_TS7400 }, \
         { 0, NULL }, /* end */  \
 }
 
