@@ -1,6 +1,6 @@
 /*
  *  Hamlib Kenwood backend - main file
- *  Copyright (c) 2000-2009 by Stephane Fillod
+ *  Copyright (c) 2000-2011 by Stephane Fillod
  *  Copyright (C) 2009 Alessandro Zummo <a.zummo@towertech.it>
  *
  *
@@ -100,6 +100,7 @@ static const struct kenwood_id_string kenwood_id_string_list[] = {
 	{ RIG_MODEL_THD7A,	"TH-D7" },
 	{ RIG_MODEL_THD7AG,	"TH-D7G" },
 	{ RIG_MODEL_TMD700,	"TM-D700" },
+	{ RIG_MODEL_THD72A,	"TH-D72" },
 	{ RIG_MODEL_TMV7,	"TM-V7" },
 	{ RIG_MODEL_THF6A,	"TH-F6" },
 	{ RIG_MODEL_THF7E,	"TH-F7" },
@@ -1749,18 +1750,23 @@ int kenwood_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 	return RIG_OK;
 }
 
-
-/*
- * kenwood_set_ptt
- */
 int kenwood_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
+	const char *ptt_cmd;
+
 	rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
 	if (!rig)
 		return -RIG_EINVAL;
 
-	return kenwood_simple_cmd(rig, (ptt == RIG_PTT_ON) ? "TX" : "RX");
+	switch (ptt) {
+		case RIG_PTT_ON:      ptt_cmd = "TX"; break;
+		case RIG_PTT_ON_MIC:  ptt_cmd = "TX0"; break;
+		case RIG_PTT_ON_DATA: ptt_cmd = "TX1"; break;
+		case RIG_PTT_OFF: ptt_cmd = "RX"; break;
+		default: return -RIG_EINVAL;
+	}
+	return kenwood_simple_cmd(rig, ptt_cmd);
 }
 
 int kenwood_set_ptt_safe(RIG *rig, vfo_t vfo, ptt_t ptt)
@@ -2450,6 +2456,7 @@ DECLARE_INITRIG_BACKEND(kenwood)
 
 	rig_register(&tmd700_caps);
 	rig_register(&thd7a_caps);
+	rig_register(&thd72a_caps);
 	rig_register(&thf7e_caps);
 	rig_register(&thg71_caps);
 	rig_register(&tmv7_caps);
@@ -2458,5 +2465,8 @@ DECLARE_INITRIG_BACKEND(kenwood)
 	rig_register(&ts590_caps);
 	rig_register(&ts480_caps);
 	rig_register(&thf6a_caps);
+
+	rig_register(&transfox_caps);
+
 	return RIG_OK;
 }
