@@ -1,6 +1,6 @@
 /*
  *  Hamlib Kenwood backend - main header
- *  Copyright (c) 2000-2009 by Stephane Fillod
+ *  Copyright (c) 2000-2011 by Stephane Fillod
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -71,6 +71,7 @@ struct kenwood_priv_data {
     int k2_ext_lvl;		/* Initial K2 extension level */
     int k3_ext_lvl;		/* Initial K3 extension level */
     int k2_md_rtty;		/* K2 RTTY mode available flag, 1 = RTTY, 0 = N/A */
+    char k3_fw_rev[KENWOOD_MAX_BUF_LEN]; /* K3 firmware revision level */
 };
 
 #define kenwood_caps(rig) ((struct kenwood_priv_caps *)(rig)->caps->priv)
@@ -161,6 +162,7 @@ extern const struct rig_caps k3_caps;
 extern const struct rig_caps trc80_caps;
 
 extern const struct rig_caps thd7a_caps;
+extern const struct rig_caps thd72a_caps;
 extern const struct rig_caps tmd700_caps;
 extern const struct rig_caps thf7a_caps;
 extern const struct rig_caps thf7e_caps;
@@ -177,6 +179,8 @@ extern const struct rig_caps ts480_caps;
 extern const struct rig_caps ts590_caps;
 extern const struct rig_caps thf6a_caps;
 
+extern const struct rig_caps transfox_caps;
+
 /* use when not interested in the answer, but want to check its len */
 static int inline kenwood_simple_transaction(RIG *rig, const char *cmd, size_t expected)
 {
