@@ -1,8 +1,7 @@
 /*
  *  Hamlib Kenwood backend - TM-D700 description
- *  Copyright (c) 2000-2008 by Stephane Fillod
+ *  Copyright (c) 2000-2010 by Stephane Fillod
  *
- *	$Id: tmd700.c,v 1.10 2009-01-28 23:30:54 azummo Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -25,10 +24,12 @@
 #endif
 
 #include <stdlib.h>
+#include <math.h>
 
-#include <hamlib/rig.h>
+#include "hamlib/rig.h"
 #include "kenwood.h"
 #include "th.h"
+#include "tones.h"
 
 
 #define TMD700_MODES	  (RIG_MODE_FM|RIG_MODE_AM)
@@ -38,8 +39,10 @@
 #define TMD700_FUNC_ALL (RIG_FUNC_TSQL|   \
                        RIG_FUNC_AIP|    \
                        RIG_FUNC_MON|    \
+                       RIG_FUNC_MUTE|   \
                        RIG_FUNC_SQL|    \
                        RIG_FUNC_TONE|   \
+                       RIG_FUNC_TBURST| \
                        RIG_FUNC_REV|    \
                        RIG_FUNC_LOCK|   \
                        RIG_FUNC_ARO)
@@ -50,24 +53,45 @@
                         RIG_LEVEL_RF|\
                         RIG_LEVEL_MICGAIN)
 
-#define TMD700_PARMS	(RIG_PARM_BACKLIGHT)
+#define TMD700_PARMS	(RIG_PARM_BACKLIGHT|\
+                        RIG_PARM_BEEP|\
+                        RIG_PARM_APO)
 
 #define TMD700_VFO_OP (RIG_OP_UP|RIG_OP_DOWN)
 
+#define TMD700_CHANNEL_CAPS   \
+            TH_CHANNEL_CAPS,\
+            .flags=1,   \
+            .dcs_code=1,    \
+            .dcs_sql=1, 
+
+#define TMD700_CHANNEL_CAPS_WO_LO \
+            TH_CHANNEL_CAPS,\
+            .dcs_code=1,    \
+            .dcs_sql=1, 
+
 /*
  * TODO: Band A & B
  */
 #define TMD700_VFO (RIG_VFO_A|RIG_VFO_B)
 
+static rmode_t tmd700_mode_table[KENWOOD_MODE_TABLE_MAX] = {
+    [0] = RIG_MODE_FM,
+    [1] = RIG_MODE_AM,
+};
+
 static struct kenwood_priv_caps  tmd700_priv_caps  = {
     .cmdtrm =  EOM_TH,   /* Command termination character */
+    .mode_table = tmd700_mode_table,
 };
 
 
+
 /*
  * TM-D700 rig capabilities.
  *
- * specs from http://www.geocities.jp/hkwatarin/TM-D700/English/spec.htm
+ * specs: http://www.geocities.jp/hkwatarin/TM-D700/English/spec.htm
+ * protocol: http://www.qsl.net/k/k7jar//pages/D700Cmds.html
  */
 const struct rig_caps tmd700_caps = {
 .rig_model =  RIG_MODEL_TMD700,
@@ -75,7 +99,7 @@ const struct rig_caps tmd700_caps = {
 .mfg_name =  "Kenwood",
 .version =  TH_VER,
 .copyright =  "LGPL",
-.status =  RIG_STATUS_UNTESTED,
+.status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_MOBILE|RIG_FLAG_APRS|RIG_FLAG_TNC,
 .ptt_type =  RIG_PTT_RIG,
 .dcd_type =  RIG_DCD_RIG,
@@ -88,7 +112,7 @@ const struct rig_caps tmd700_caps = {
 .serial_handshake =  RIG_HANDSHAKE_NONE,
 .write_delay =  0,
 .post_write_delay =  0,
-.timeout =  200,
+.timeout =  1000,
 .retry =  3,
 
 .has_get_func =  TMD700_FUNC_ALL,
@@ -98,30 +122,32 @@ const struct rig_caps tmd700_caps = {
 .has_get_parm =  TMD700_PARMS,
 .has_set_parm =  TMD700_PARMS,    /* FIXME: parms */
 .level_gran = {
-        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 5 } },
-        [LVL_SQL] = { .min = { .i = 0 }, .max = { .i = 5 } },
-        [LVL_RFPOWER] = { .min = { .i = 3 }, .max = { .i = 0 } },
+        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 7 } },
+        [LVL_SQL] = { .min = { .i = 0 }, .max = { .i = 0x1f }, .step = { .f = 1./0x1f } },
+        [LVL_RFPOWER] = { .min = { .i = 2 }, .max = { .i = 0 }, .step = { .f = 1./3. }  },
+        [LVL_AF] = { .min = { .i = 0 }, .max = { .i = 0x3f }, .step = { .f = 1./0x3f } },
 },
 .parm_gran =  {},
 .ctcss_list =  kenwood38_ctcss_list,
-.dcs_list =  NULL,
+.dcs_list =  common_dcs_list,
 .preamp =   { RIG_DBLST_END, },
 .attenuator =   { RIG_DBLST_END, },
 .max_rit =  Hz(0),
 .max_xit =  Hz(0),
 .max_ifshift =  Hz(0),
 .vfo_ops =  TMD700_VFO_OP,
-.targetable_vfo =  RIG_TARGETABLE_FREQ,
+.scan_ops = RIG_SCAN_VFO,
+.targetable_vfo =  RIG_TARGETABLE_NONE,
 .transceive =  RIG_TRN_RIG,
 .bank_qty =   0,
-.chan_desc_sz =  0,
+.chan_desc_sz =  8,
 
-.chan_list =  {
-                {  1,  199, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* normal MEM */
-                {  200,219, RIG_MTYPE_EDGE , {TH_CHANNEL_CAPS}}, /* U/L MEM */
-                {  221,222, RIG_MTYPE_CALL, {TH_CHANNEL_CAPS}},  /* Call 0/1 */
-                RIG_CHAN_END,
-                   },
+.chan_list = {
+    {  1,  199, RIG_MTYPE_MEM ,  {TMD700_CHANNEL_CAPS}},  /* normal MEM */
+    {  200,219, RIG_MTYPE_EDGE , {TMD700_CHANNEL_CAPS}}, /* U/L MEM */
+    {  221,222, RIG_MTYPE_CALL,  {TMD700_CHANNEL_CAPS_WO_LO}},  /* Call 0/1 */
+    RIG_CHAN_END,
+       },
 /*
  * TODO: Japan & TM-D700S, and Taiwan models
  */
@@ -151,7 +177,6 @@ const struct rig_caps tmd700_caps = {
 	RIG_FRNG_END,
   }, /* tx range */
 
-/* TBC */
 .tuning_steps =  {
 	 {TMD700_MODES,kHz(5)},
 	 {TMD700_MODES,kHz(6.25)},
@@ -179,10 +204,16 @@ const struct rig_caps tmd700_caps = {
 .get_freq =  th_get_freq,
 .set_mode =  th_set_mode,
 .get_mode =  th_get_mode,
-.set_vfo =  th_set_vfo,
+.set_vfo =  tm_set_vfo_bc2,
 .get_vfo =  th_get_vfo,
+.set_split_vfo =  th_set_split_vfo,
+.get_split_vfo =  th_get_split_vfo,
 .set_ctcss_tone =  th_set_ctcss_tone,
 .get_ctcss_tone =  th_get_ctcss_tone,
+.set_ctcss_sql =  th_set_ctcss_sql,
+.get_ctcss_sql =  th_get_ctcss_sql,
+.set_dcs_sql =  th_set_dcs_sql,
+.get_dcs_sql =  th_get_dcs_sql,
 .set_mem =  th_set_mem,
 .get_mem =  th_get_mem,
 .set_channel =  th_set_channel,
@@ -190,11 +221,17 @@ const struct rig_caps tmd700_caps = {
 .set_trn =  th_set_trn,
 .get_trn =  th_get_trn,
 
+.set_func =  th_set_func,
 .get_func =  th_get_func,
+.set_level =  th_set_level,
 .get_level =  th_get_level,
+.set_parm =  th_set_parm,
 .get_parm =  th_get_parm,
 .get_info =  th_get_info,
 .get_dcd =  th_get_dcd,
+.set_ptt =  th_set_ptt,
+.vfo_op =  th_vfo_op,
+.scan   =  th_scan,
 
 .decode_event =  th_decode_event,
 };
