@@ -48,16 +48,17 @@
 #include "si570avrusb.h"
 
 static int si570avrusb_init(RIG *rig);
-static int si570avrusb_cleanup(RIG *rig);
-static int si570avrusb_open(RIG *rig);
-static int si570avrusb_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
-static int si570avrusb_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
-static int si570avrusb_set_freq_by_value(RIG *rig, vfo_t vfo, freq_t freq);
-static int si570avrusb_get_freq_by_value(RIG *rig, vfo_t vfo, freq_t *freq);
-static int si570avrusb_set_ptt(RIG * rig, vfo_t vfo, ptt_t ptt);
-static int si570avrusb_set_conf(RIG *rig, token_t token, const char *val);
-static int si570avrusb_get_conf(RIG *rig, token_t token, char *val);
-static const char *si570avrusb_get_info(RIG *rig);
+static int si570picusb_init(RIG *rig);
+static int si570xxxusb_cleanup(RIG *rig);
+static int si570xxxusb_open(RIG *rig);
+static int si570xxxusb_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
+static int si570xxxusb_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
+static int si570xxxusb_set_freq_by_value(RIG *rig, vfo_t vfo, freq_t freq);
+static int si570xxxusb_get_freq_by_value(RIG *rig, vfo_t vfo, freq_t *freq);
+static int si570xxxusb_set_ptt(RIG * rig, vfo_t vfo, ptt_t ptt);
+static int si570xxxusb_set_conf(RIG *rig, token_t token, const char *val);
+static int si570xxxusb_get_conf(RIG *rig, token_t token, char *val);
+static const char *si570xxxusb_get_info(RIG *rig);
 
 
 
@@ -68,20 +69,28 @@ static const char *si570avrusb_get_info(RIG *rig);
  */
 
 #define VENDOR_NAME			"www.obdev.at"
-#define PRODUCT_NAME		"DG8SAQ-I2C"
-
+#define AVR_PRODUCT_NAME		"DG8SAQ-I2C"
+#define PIC_PRODUCT_NAME		"KTH-SDR-KIT"
 
 
 #define TOK_OSCFREQ	TOKEN_BACKEND(1)
 #define TOK_MULTIPLIER	TOKEN_BACKEND(3)
+#define TOK_I2C_ADDR	TOKEN_BACKEND(4)
+#define TOK_BPF     	TOKEN_BACKEND(5)
 
-static const struct confparams si570avrusb_cfg_params[] = {
+static const struct confparams si570xxxusb_cfg_params[] = {
 	{ TOK_OSCFREQ, "osc_freq", "Oscillator freq", "Oscillator frequency in Hz",
 			"114285000", RIG_CONF_NUMERIC, { .n = { 1, MHz(300), 1 } }
 	},
 	{ TOK_MULTIPLIER, "multiplier", "Freq Multiplier", "Frequency multiplier",
 		"4", RIG_CONF_NUMERIC, { .n = { 0.000001, 100 } }
 	},
+	{ TOK_I2C_ADDR, "i2c_addr", "I2C Address", "Si570 I2C Address",
+		"55", RIG_CONF_NUMERIC, { .n = { 0, 512 } }
+	},
+	{ TOK_BPF, "bpf", "BPF", "Enable Band Pass Filter",
+		"0", RIG_CONF_CHECKBUTTON, { }
+	},
 	{ RIG_CONF_END, NULL, }
 };
 
@@ -89,12 +98,15 @@ static const struct confparams si570avrusb_cfg_params[] = {
 /*
  * Common data struct
  */
-struct si570avrusb_priv_data {
+struct si570xxxusb_priv_data {
 
 	unsigned short version;		/* >=0x0f00 is PE0FKO's */
 
 	double osc_freq;	/* MHz */
 	double multiplier;	/* default to 4 for QSD/QSE */
+
+	int i2c_addr;
+	int bpf;    /* enable BPF? */
 };
 
 #define SI570AVRUSB_MODES (RIG_MODE_USB)	/* USB is for SDR */
@@ -124,7 +136,7 @@ const struct rig_caps si570avrusb_caps = {
 .rig_model =  RIG_MODEL_SI570AVRUSB,
 .model_name = "Si570 AVR-USB",
 .mfg_name =  "SoftRock",
-.version =  "0.1",
+.version =  "0.2",
 .copyright =  "GPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_TUNER,
@@ -177,29 +189,111 @@ const struct rig_caps si570avrusb_caps = {
 .filters =  {
 		RIG_FLT_END,
 	},
-.cfgparams =  si570avrusb_cfg_params,
+.cfgparams =  si570xxxusb_cfg_params,
 
 .rig_init =     si570avrusb_init,
-.rig_cleanup =  si570avrusb_cleanup,
-.rig_open =     si570avrusb_open,
-.set_conf =  si570avrusb_set_conf,
-.get_conf =  si570avrusb_get_conf,
+.rig_cleanup =  si570xxxusb_cleanup,
+.rig_open =     si570xxxusb_open,
+.set_conf =  si570xxxusb_set_conf,
+.get_conf =  si570xxxusb_get_conf,
 
-.set_freq    =  si570avrusb_set_freq,
-.get_freq    =  si570avrusb_get_freq,
-.set_ptt    =  si570avrusb_set_ptt,
-.get_info    =  si570avrusb_get_info,
+.set_freq    =  si570xxxusb_set_freq,
+.get_freq    =  si570xxxusb_get_freq,
+.set_ptt    =  si570xxxusb_set_ptt,
+.get_info    =  si570xxxusb_get_info,
+
+};
+
+
+/*
+ * KTH-SDR-KIT Si570 PIC-USB description
+ *
+ * Same USB interface as AVR-USB, except different product string
+ * and different multiplier.
+ *
+ *   http://home.kpn.nl/rw.engberts/sdr_kth.htm
+ */
+const struct rig_caps si570picusb_caps = {
+.rig_model =  RIG_MODEL_SI570PICUSB,
+.model_name = "Si570 PIC-USB",
+.mfg_name =  "KTH-SDR kit",
+.version =  "0.2",
+.copyright =  "GPL",
+.status =  RIG_STATUS_BETA,
+.rig_type =  RIG_TYPE_TUNER,
+.ptt_type =  RIG_PTT_NONE,
+.dcd_type =  RIG_DCD_NONE,
+.port_type =  RIG_PORT_USB,
+.write_delay =  0,
+.post_write_delay =  0,
+.timeout =  500,
+.retry = 0,
+
+.has_get_func =  SI570AVRUSB_FUNC,
+.has_set_func =  SI570AVRUSB_FUNC,
+.has_get_level =  SI570AVRUSB_LEVEL_ALL,
+.has_set_level =  RIG_LEVEL_SET(SI570AVRUSB_LEVEL_ALL),
+.has_get_parm =  SI570AVRUSB_PARM_ALL,
+.has_set_parm =  RIG_PARM_SET(SI570AVRUSB_PARM_ALL),
+.level_gran =  {},
+.parm_gran =  {},
+.ctcss_list =  NULL,
+.dcs_list =  NULL,
+.preamp =   { RIG_DBLST_END },
+.attenuator =   { RIG_DBLST_END }, /* TODO */
+.max_rit =  Hz(0),
+.max_xit =  Hz(0),
+.max_ifshift =  Hz(0),
+.targetable_vfo =  0,
+.transceive =  RIG_TRN_OFF,
+.bank_qty =   0,
+.chan_desc_sz =  0,
+
+.chan_list =  { RIG_CHAN_END, },
+
+.rx_range_list1 =  {
+    {kHz(800),MHz(550),SI570AVRUSB_MODES,-1,-1,SI570AVRUSB_VFO},
+	RIG_FRNG_END,
+  },
+.tx_range_list1 =  { RIG_FRNG_END, },
+.rx_range_list2 =  {
+    {kHz(800),MHz(550),SI570AVRUSB_MODES,-1,-1,SI570AVRUSB_VFO},
+	RIG_FRNG_END,
+  },
+.tx_range_list2 =  { RIG_FRNG_END, },
+.tuning_steps =  {
+	 {SI570AVRUSB_MODES,Hz(1)},
+	 RIG_TS_END,
+	},
+        /* mode/filter list, remember: order matters! */
+.filters =  {
+		RIG_FLT_END,
+	},
+.cfgparams =  si570xxxusb_cfg_params,
+
+.rig_init =     si570picusb_init,
+.rig_cleanup =  si570xxxusb_cleanup,
+.rig_open =     si570xxxusb_open,
+.set_conf =  si570xxxusb_set_conf,
+.get_conf =  si570xxxusb_get_conf,
+
+.set_freq    =  si570xxxusb_set_freq,
+.get_freq    =  si570xxxusb_get_freq,
+.get_info    =  si570xxxusb_get_info,
 
 };
 
 
 
+/*
+ * AVR-USB model
+ */
 int si570avrusb_init(RIG *rig)
 {
 	hamlib_port_t *rp = &rig->state.rigport;
-	struct si570avrusb_priv_data *priv;
+	struct si570xxxusb_priv_data *priv;
 
-	priv = (struct si570avrusb_priv_data*)calloc(sizeof(struct si570avrusb_priv_data), 1);
+	priv = (struct si570xxxusb_priv_data*)calloc(sizeof(struct si570xxxusb_priv_data), 1);
 	if (!priv) {
 		/* whoops! memory shortage! */
 		return -RIG_ENOMEM;
@@ -209,21 +303,66 @@ int si570avrusb_init(RIG *rig)
     /* QSD/QSE */
 	priv->multiplier = 4;
 
+	priv->i2c_addr = SI570_I2C_ADDR;
+	/* disable BPF, because it may share PTT I/O line */
+	priv->bpf = 0;
+
 	rp->parm.usb.vid = USBDEV_SHARED_VID;
 	rp->parm.usb.pid = USBDEV_SHARED_PID;
+
+	/* no usb_set_configuration() and usb_claim_interface() */
+	rp->parm.usb.iface = -1;
 	rp->parm.usb.conf = 1;
-	rp->parm.usb.iface = 0;
 	rp->parm.usb.alt = 0;	/* necessary ? */
 
 	rp->parm.usb.vendor_name = VENDOR_NAME;
-	rp->parm.usb.product = PRODUCT_NAME;
+	rp->parm.usb.product = AVR_PRODUCT_NAME;
 
 	rig->state.priv = (void*)priv;
 
 	return RIG_OK;
 }
 
-int si570avrusb_cleanup(RIG *rig)
+/*
+ * PIC-USB model
+ */
+int si570picusb_init(RIG *rig)
+{
+	hamlib_port_t *rp = &rig->state.rigport;
+	struct si570xxxusb_priv_data *priv;
+
+	priv = (struct si570xxxusb_priv_data*)calloc(sizeof(struct si570xxxusb_priv_data), 1);
+	if (!priv) {
+		/* whoops! memory shortage! */
+		return -RIG_ENOMEM;
+	}
+
+	priv->osc_freq = SI570_NOMINAL_XTALL_FREQ;
+    /* QSD/QSE */
+	priv->multiplier = 2;
+
+	priv->i2c_addr = SI570_I2C_ADDR;
+    /* enable BPF, because this is kit is receiver only */
+	priv->bpf = 1;
+
+	rp->parm.usb.vid = USBDEV_SHARED_VID;
+	rp->parm.usb.pid = USBDEV_SHARED_PID;
+
+	/* no usb_set_configuration() and usb_claim_interface() */
+	rp->parm.usb.iface = -1;
+	rp->parm.usb.conf = 1;
+	rp->parm.usb.alt = 0;	/* necessary ? */
+
+	rp->parm.usb.vendor_name = VENDOR_NAME;
+	rp->parm.usb.product = PIC_PRODUCT_NAME;
+
+	rig->state.priv = (void*)priv;
+
+	return RIG_OK;
+}
+
+
+int si570xxxusb_cleanup(RIG *rig)
 {
 	if (!rig)
 		return -RIG_EINVAL;
@@ -235,36 +374,50 @@ int si570avrusb_cleanup(RIG *rig)
 	return RIG_OK;
 }
 
-int si570avrusb_set_conf(RIG *rig, token_t token, const char *val)
+int si570xxxusb_set_conf(RIG *rig, token_t token, const char *val)
 {
-	struct si570avrusb_priv_data *priv;
+	struct si570xxxusb_priv_data *priv;
 	freq_t freq;
 	double multiplier;
+	int i2c_addr;
 
-	priv = (struct si570avrusb_priv_data*)rig->state.priv;
+	priv = (struct si570xxxusb_priv_data*)rig->state.priv;
 
 	switch(token) {
 		case TOK_OSCFREQ:
-			sscanf(val, "%"SCNfreq, &freq);
+			if (sscanf(val, "%"SCNfreq, &freq) != 1)
+				return -RIG_EINVAL;
 			priv->osc_freq = (double)freq/1e6;
 			break;
 		case TOK_MULTIPLIER:
-			sscanf(val, "%lf", &multiplier);
+			if (sscanf(val, "%lf", &multiplier) != 1)
+				return -RIG_EINVAL;
 			if (multiplier == 0.)
 				return -RIG_EINVAL;
 			priv->multiplier = multiplier;
 			break;
+		case TOK_I2C_ADDR:
+			if (sscanf(val, "%x", &i2c_addr) != 1)
+				return -RIG_EINVAL;
+			if (i2c_addr < 0 || i2c_addr >= (1<<9))
+				return -RIG_EINVAL;
+			priv->i2c_addr = i2c_addr;
+			break;
+		case TOK_BPF:
+			if (sscanf(val, "%d", &priv->bpf) != 1)
+				return -RIG_EINVAL;
+			break;
 		default:
 			return -RIG_EINVAL;
 	}
 	return RIG_OK;
 }
 
-int si570avrusb_get_conf(RIG *rig, token_t token, char *val)
+int si570xxxusb_get_conf(RIG *rig, token_t token, char *val)
 {
-	struct si570avrusb_priv_data *priv;
+	struct si570xxxusb_priv_data *priv;
 
-	priv = (struct si570avrusb_priv_data*)rig->state.priv;
+	priv = (struct si570xxxusb_priv_data*)rig->state.priv;
 
 	switch(token) {
 		case TOK_OSCFREQ:
@@ -273,6 +426,12 @@ int si570avrusb_get_conf(RIG *rig, token_t token, char *val)
 		case TOK_MULTIPLIER:
 			sprintf(val, "%f", priv->multiplier);
 			break;
+		case TOK_I2C_ADDR:
+			sprintf(val, "%x", priv->i2c_addr);
+			break;
+		case TOK_BPF:
+			sprintf(val, "%d", priv->bpf);
+			break;
 		default:
 			return -RIG_EINVAL;
 	}
@@ -316,9 +475,9 @@ static int setBPF(RIG *rig, int enable)
     return RIG_OK;
 }
 
-int si570avrusb_open(RIG *rig)
+int si570xxxusb_open(RIG *rig)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
 	int ret;
 	unsigned short version;
@@ -341,7 +500,7 @@ int si570avrusb_open(RIG *rig)
 	}
 
 	priv->version = version;
-	if (version  >= 0x0F00)
+	if (version  >= 0x0F00 || rig->caps->rig_model == RIG_MODEL_SI570PICUSB)
 	{
 		unsigned int iFreq;
 
@@ -357,9 +516,11 @@ int si570avrusb_open(RIG *rig)
 
 		priv->osc_freq = (double)iFreq / (1UL<<24);
 
-        ret = setBPF(rig, 1);
-        if (ret != RIG_OK)
-            return ret;
+		if (priv->bpf) {
+			ret = setBPF(rig, 1);
+			if (ret != RIG_OK)
+				return ret;
+		}
 	}
 
 	rig_debug(RIG_DEBUG_VERBOSE,"%s: using Xtall at %.3f MHz\n",
@@ -368,7 +529,8 @@ int si570avrusb_open(RIG *rig)
 	return RIG_OK;
 }
 
-const char * si570avrusb_get_info(RIG *rig)
+
+const char * si570xxxusb_get_info(RIG *rig)
 {
 	static char buf[64];
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
@@ -398,7 +560,7 @@ static const int HS_DIV_MAP[] = {4,5,6,7,-1,9,-1,11};
 
 static int calcDividers(RIG *rig, double f, struct solution* solution)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 	struct solution sols[8]; 
 	int i;
 	int imin;
@@ -467,14 +629,14 @@ static void setLongWord(uint32_t value, unsigned char * bytes)
 } 
 
 
-int si570avrusb_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
+int si570xxxusb_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
 	int ret;
 	unsigned char buffer[6];
 	int request = REQUEST_SET_FREQ;
-	int value = 0x700 + SI570_I2C_ADDR;
+	int value = 0x700 + priv->i2c_addr;
 	int index = 0;
 	double f;
 	struct solution theSolution;
@@ -483,8 +645,8 @@ int si570avrusb_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 	unsigned char fracBuffer[4];
 	unsigned char intBuffer[4];
 
-	if (priv->version >= 0x0f00)
-		return si570avrusb_set_freq_by_value(rig, vfo, freq);
+	if (priv->version >= 0x0f00 || rig->caps->rig_model == RIG_MODEL_SI570PICUSB)
+		return si570xxxusb_set_freq_by_value(rig, vfo, freq);
 
 	f = (freq * priv->multiplier)/1e6;
 
@@ -526,18 +688,18 @@ int si570avrusb_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 	return RIG_OK;
 }
 
-int si570avrusb_set_freq_by_value(RIG *rig, vfo_t vfo, freq_t freq)
+int si570xxxusb_set_freq_by_value(RIG *rig, vfo_t vfo, freq_t freq)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
 	int ret;
 
 	unsigned char buffer[4];
 	int request = REQUEST_SET_FREQ_BY_VALUE;
-	int value = 0x700 + SI570_I2C_ADDR;
+	int value = 0x700 + priv->i2c_addr;
 	int index = 0;
 	double f;
-       
+
 	f = (freq * priv->multiplier)/1e6;
 
 	setLongWord(round(f * 2097152.0), buffer);
@@ -564,7 +726,7 @@ int si570avrusb_set_freq_by_value(RIG *rig, vfo_t vfo, freq_t freq)
 
 static double calculateFrequency(RIG *rig, const unsigned char * buffer)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 
 	int RFREQ_int = ((buffer[2] & 0xf0) >> 4) + ((buffer[1] & 0x3f) * 16);
 	int RFREQ_frac = (256 * 256 * 256 * (buffer[2] & 0xf)) + (256 * 256 * buffer[3]) + (256 * buffer[4]) + (buffer[5]);
@@ -591,18 +753,18 @@ static double calculateFrequency(RIG *rig, const unsigned char * buffer)
 	return fout;
 }
 
-int si570avrusb_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
+int si570xxxusb_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
 	unsigned char buffer[6];
 	int ret;
 
-	if (priv->version >= 0x0f00)
-		return si570avrusb_get_freq_by_value(rig, vfo, freq);
+	if (priv->version >= 0x0f00 || rig->caps->rig_model == RIG_MODEL_SI570PICUSB)
+		return si570xxxusb_get_freq_by_value(rig, vfo, freq);
 
 	ret = usb_control_msg(udh, USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
-			REQUEST_READ_REGISTERS, SI570_I2C_ADDR, 0,
+			REQUEST_READ_REGISTERS, priv->i2c_addr, 0,
 			(char *)buffer, sizeof(buffer), rig->state.rigport.timeout);
 
 	if (ret <= 0) {
@@ -617,9 +779,9 @@ int si570avrusb_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 	return RIG_OK;
 }
 
-int si570avrusb_get_freq_by_value(RIG *rig, vfo_t vfo, freq_t *freq)
+int si570xxxusb_get_freq_by_value(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-	struct si570avrusb_priv_data *priv = (struct si570avrusb_priv_data *)rig->state.priv;
+	struct si570xxxusb_priv_data *priv = (struct si570xxxusb_priv_data *)rig->state.priv;
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
 	int ret;
 	uint32_t iFreq;
@@ -641,7 +803,7 @@ int si570avrusb_get_freq_by_value(RIG *rig, vfo_t vfo, freq_t *freq)
 }
 
 
-int si570avrusb_set_ptt(RIG * rig, vfo_t vfo, ptt_t ptt)
+int si570xxxusb_set_ptt(RIG * rig, vfo_t vfo, ptt_t ptt)
 {
 	struct usb_dev_handle *udh = rig->state.rigport.handle;
 	int ret;
