@@ -7,7 +7,6 @@
  * Common yaesu declarations for hamlib
  *
  *
- *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
@@ -68,10 +67,12 @@ extern const struct rig_caps ft1000mpmkv_caps;
 extern const struct rig_caps ft1000mpmkvfld_caps;
 extern const struct rig_caps ft1000d_caps;
 extern const struct rig_caps ft2000_caps;
+extern const struct rig_caps ftdx5000_caps;
 extern const struct rig_caps ft9000_caps;
 extern const struct rig_caps frg100_caps;
 extern const struct rig_caps frg8800_caps;
 extern const struct rig_caps frg9600_caps;
 extern const struct rig_caps vr5000_caps;
+extern const struct rig_caps vx1700_caps;
 
 #endif /* _YAESU_H */
